==> moltres-0.5.8.tgz: package/README.md <==
# moltres

Firebase application framework.

This application framework provides functionality for building a full stack
application on firebase. The application structure is built using firebase,
redux, react, react-native and react-native-web.

An app built using moltres is a full fledged mobile app (iOS and Android) as well as web app.


## Project Status

[![license](https://img.shields.io/npm/l/moltres.svg)](https://github.com/brianneisler/moltres/blob/master/LICENSE)
[![npm version](https://badge.fury.io/js/moltres.svg)](https://badge.fury.io/js/moltres)
[![Build
Status](https://travis-ci.com/brianneisler/moltres.svg)](https://travis-ci.com/brianneisler/moltres)
[![codecov](https://codecov.io/gh/brianneisler/moltres/branch/master/graph/badge.svg)](https://codecov.io/gh/brianneisler/moltres)<br/>
[![NPM](https://nodei.co/npm/moltres.png?downloads=true&downloadRank=true&stars=true)](https://nodei.co/npm/moltres/)


## Documentation

[Full API documentation](docs/API.md) - Learn about each method


## Getting Started

Setup your firebase application on https://firebase.google.com/


## Install

```sh
npm install -g moltres
```


### Creating a new application
* Initialize a new application (this will download the application [moltres-template](https://github.com/brianneisler/moltres-template/))
```sh
moltres init -n newapp
```
* Modify the application name in `package.json`
* Follow the steps in [moltres-template/DEVELOPMENT.md](https://github.com/brianneisler/moltres-template/blob/master/DEVELOPMENT.md) to get your application
  running.

==> moltres-0.5.11.tgz: package/README.md <==
# moltres

Firebase application framework.

This application framework provides functionality for building a full stack
application on firebase. The application structure is built using firebase,
redux, react, react-native and react-native-web.

An app built using moltres is a full fledged mobile app (iOS and Android) as well as web app.

## Project Status

[![license](https://img.shields.io/npm/l/moltres.svg)](https://github.com/brianneisler/moltres/blob/master/LICENSE)
[![npm version](https://badge.fury.io/js/moltres.svg)](https://badge.fury.io/js/moltres)
[![Build
Status](https://travis-ci.com/brianneisler/moltres.svg)](https://travis-ci.com/brianneisler/moltres)
[![codecov](https://codecov.io/gh/brianneisler/moltres/branch/master/graph/badge.svg)](https://codecov.io/gh/brianneisler/moltres)<br/>
[![NPM](https://nodei.co/npm/moltres.png?downloads=true&downloadRank=true&stars=true)](https://nodei.co/npm/moltres/)

## Documentation

[Full API documentation](docs/API.md) - Learn about each method

## Getting Started

Setup your firebase application on https://firebase.google.com/

## Install

```sh
npm install -g moltres
```

### Creating a new application

- Initialize a new application (this will download the application [moltres-template](https://github.com/brianneisler/moltres-template/))

```sh
moltres init -n newapp
```

- Modify the application name in `package.json`
- Follow the steps in [moltres-template/DEVELOPMENT.md](https://github.com/brianneisler/moltres-template/blob/master/DEVELOPMENT.md) to get your application
  running.
